package com.qianhe.system.service.impl;

import com.qianhe.common.exception.ServiceException;
import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.StringUtils;
import com.qianhe.system.domain.*;
import com.qianhe.system.mapper.*;
import com.qianhe.system.service.IWaterOrderService;
import com.qianhe.system.vo.WaterOrderVo;
import io.swagger.models.auth.In;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 订单Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterOrderServiceImpl implements IWaterOrderService
{
    @Autowired
    private WaterOrderMapper waterOrderMapper;
    @Autowired
    private WaterOrderGoodsMapper waterOrderGoodsMapper;
    @Autowired
    private WaterGoodsMapper waterGoodsMapper;
    @Autowired
    private WaterGoodsImgMapper waterGoodsImgMapper;
    @Autowired
    private WaterGoodsCartMapper waterGoodsCartMapper;

    /**
     * 查询订单
     *
     * @param id 订单主键
     * @return 订单
     */
    @Override
    public WaterOrderVo selectWaterOrderById(Long id)
    {
        WaterOrder waterOrder = waterOrderMapper.selectWaterOrderById(id);
        //转vo
        WaterOrderVo waterOrderVo = new WaterOrderVo();
        BeanUtils.copyProperties(waterOrder,waterOrderVo);
        //查询该订单商品
        WaterOrderGoods waterOrderGoods = new WaterOrderGoods();
        waterOrderGoods.setOrderId(id);
        List<WaterOrderGoods> waterOrderGoodsList = waterOrderGoodsMapper.selectWaterOrderGoodsList(waterOrderGoods);
        //查询商品图片信息
        List<WaterGoodsImg> waterGoodsImgs = waterGoodsImgMapper.selectWaterGoodsImgList(new WaterGoodsImg());
        //订单商品集合
        List<WaterOrderGoods> waterOrderGoodsList1 = new ArrayList<>();
        if (waterOrderGoodsList.size() > 0){
            for (WaterOrderGoods waterOrderGood : waterOrderGoodsList) {
                //封面图集合
                List<WaterGoodsImg> coverImgs = new ArrayList<>();
                //详情图集合
                List<WaterGoodsImg> detailsImgs = new ArrayList<>();
                for (WaterGoodsImg waterGoodsImg : waterGoodsImgs) {
                    if (waterOrderGood.getGoodsId().equals(waterGoodsImg.getGoodsId()) && waterGoodsImg.getImgType() == 1){
                        coverImgs.add(waterGoodsImg);
                    }else if (waterOrderGood.getGoodsId().equals(waterGoodsImg.getGoodsId()) && waterGoodsImg.getImgType() == 2){
                        detailsImgs.add(waterGoodsImg);
                    }
                }
                if (coverImgs.size() > 0){
                    waterOrderGood.setCoverImgs(coverImgs);
                }
                if (detailsImgs.size() > 0){
                    waterOrderGood.setDetailsImgs(detailsImgs);
                }
                waterOrderGoodsList1.add(waterOrderGood);
            }
        }
        waterOrderVo.setWaterOrderGoodsList(waterOrderGoodsList1);
        return waterOrderVo;
    }

    /**
     * 查询订单列表
     *
     * @param waterOrderVo 订单
     * @return 订单
     */
    @Override
    public List<WaterOrder> selectWaterOrderList(WaterOrderVo waterOrderVo)
    {
        return waterOrderMapper.selectWaterOrderList(waterOrderVo);
    }

    /**
     * 新增订单
     *
     * @param waterOrderVo 订单
     * @return 结果
     */
    @Override
    @Transactional
    public int insertWaterOrder(WaterOrderVo waterOrderVo)
    {
        //判断用户下单是否有地址
        if (StringUtils.isNull(waterOrderVo.getUserAddressId())){
            throw new ServiceException("未选择地址！");
        }
        waterOrderVo.setCreateUser(waterOrderVo.getUserId().toString());
        waterOrderVo.setCreateTime(DateUtils.getNowDate());
        waterOrderVo.setOrderNum(getOrerNum());
        //判断支付方式是否为水票支付
        if(waterOrderVo.getPayType() == 2){
            //水票支付,修改订单状态为待接单
            waterOrderVo.setOrderState(2);
            waterOrderVo.setPayState(1);
            waterOrderVo.setOrderType(1);
        }else {
            //银行支付，修改订单状态为待付款
            waterOrderVo.setOrderState(1);
            waterOrderVo.setPayState(0);
            waterOrderVo.setOrderType(1);
        }
        int i = waterOrderMapper.insertWaterOrder(waterOrderVo);
        //新增订单商品
        insertWaterOrderGoods(waterOrderVo);
        return i;
    }

    /**
     * 生成订单编号
     * @return
     */
    private String getOrerNum(){
        String orderNum = "";
        //获取当前年月日
        SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
        String today = format.format(DateUtils.getNowDate());
        Long rqbh = Long.parseLong(today + "0001");
        while (true){
            WaterOrder waterOrder = new WaterOrder();
            waterOrder.setOrderNum(rqbh.toString());
            WaterOrder waterOrder1 = waterOrderMapper.selectWaterOrderNumByOrderNum(rqbh.toString());
            if (StringUtils.isNotNull(waterOrder1)){
                rqbh ++;
            }else {
                break;
            }
        }
        //生成随机四位英文字母
        Random random = new Random();
        String randomletters = "";
        for (int i = 0; i < 4; i++) {
            int index = random.nextInt(26);
            char letter = (char) ('A' + index);
            randomletters += letter;
        }
        orderNum = rqbh + randomletters;
        return orderNum;
    }

    private void insertWaterOrderGoods(WaterOrderVo waterOrderVo) {
        List<WaterOrderGoods> waterOrderGoodsList = waterOrderVo.getWaterOrderGoodsList();
        //商品订单主键id
        Long id = waterOrderVo.getId();
        //商品订单编号
        String orderNum = waterOrderVo.getOrderNum();
        if (StringUtils.isNotNull(waterOrderGoodsList)){
            for (WaterOrderGoods waterOrderGoods : waterOrderGoodsList) {
                //判断是否从购物车下单
                if (waterOrderVo.getOrderGoodsType() == 2){
                    //从购物车下单之后，对应商品将从购物车中清除
                    //根据商品信息查询购物车商品信息
                    WaterGoodsCart waterGoodsCart = new WaterGoodsCart();
                    waterGoodsCart.setUserId(waterOrderVo.getUserId());
                    waterGoodsCart.setGoodsId(waterOrderGoods.getGoodsId());
                    waterGoodsCart.setGoodsSpeVal(waterOrderGoods.getGoodsSpe());
                    List<WaterGoodsCart> list = waterGoodsCartMapper.selectWaterGoodsCartList(waterGoodsCart);
                    WaterGoodsCart waterGoodsCart1 = list.get(0);
                    //删除购物车商品
                    waterGoodsCartMapper.deleteWaterGoodsCartById(waterGoodsCart1.getId());
                }
                //根据商品id查询商品信息
                WaterGoods waterGoods = waterGoodsMapper.selectWaterGoodsById(waterOrderGoods.getGoodsId());
                //判断商品是否下架
                if (waterGoods.getStatus() == 0) {
                    throw new ServiceException("该商品已下架，请您重新选择商品！");
                }
                waterOrderGoods.setOrderId(id);
                waterOrderGoods.setOrderNum(orderNum);
                waterOrderGoods.setGoodsTypeId(waterGoods.getGoodsTypeId());
                waterOrderGoods.setGoodsTitle(waterGoods.getTitle());
                waterOrderGoods.setCreateUser(waterOrderVo.getUserId().toString());
                waterOrderGoods.setCreateTime(DateUtils.getNowDate());
            }
            //批量新增订单商品
            waterOrderMapper.batchInsertWaterOrderGoods(waterOrderGoodsList);
        }
    }

    /**
     * 修改订单
     *
     * @param waterOrderVo 订单
     * @return 结果
     */
    @Override
    @Transactional
    public int updateWaterOrder(WaterOrderVo waterOrderVo)
    {
        //删除订单商品
        waterOrderMapper.deleteWaterOrderGoodsByOrderId(waterOrderVo.getId());
        //新增订单商品
        insertWaterOrderGoods(waterOrderVo);
        return waterOrderMapper.updateWaterOrder(waterOrderVo);
    }

    /**
     * 修改订单
     * @param waterOrderVo 订单
     * @return
     */
    @Override
    public int updateWaterOrder1(WaterOrderVo waterOrderVo) {
        return waterOrderMapper.updateWaterOrder(waterOrderVo);
    }

    /**
     * 批量删除订单
     *
     * @param ids 需要删除的订单主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteWaterOrderByIds(Long[] ids)
    {
        //批量删除订单商品
        waterOrderMapper.deleteWaterOrderGoodsByOrderIds(ids);
        return waterOrderMapper.deleteWaterOrderByIds(ids);
    }

    /**
     * 删除订单信息
     *
     * @param id 订单主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteWaterOrderById(Long id)
    {
        return waterOrderMapper.deleteWaterOrderById(id);
    }

    /**
     * 修改订单状态
     * @param waterOrderVo
     * @return
     */
    @Override
    @Transactional
    public int updateOrderState(WaterOrderVo waterOrderVo) {
        WaterOrder waterOrder = waterOrderMapper.selectWaterOrderById(waterOrderVo.getId());
        //接单时需再次查看该订单是否已经被用户所取消
        if (waterOrderVo.getOrderState() == 3){
            if (waterOrder.getOrderState() == 5){
                throw new ServiceException("该订单已被用户取消！");
            }
        }
        //判断是否需要退款
        //传过来订单状态为取消
        if (waterOrderVo.getOrderState() == 5){
            //判断该订单是否已经支付，支付后取消，需要退款，将该订单改为退款订单
            //判断该订单支付方式是否为水票支付，水票支付不涉及退款
            if (waterOrder.getPayType() == 2){
                //为水票支付，该订单状态改为已取消
                waterOrderVo.setOrderState(5);
            }else {
                //银行支付，涉及线上退款
                if (waterOrder.getOrderState() == 2){
                    //订单类型改为退款订单
                    waterOrderVo.setOrderType(2);
                    //订单状态改为进行中
                    waterOrderVo.setOrderState(3);
                    //此时取消原因为退款原因
                    waterOrderVo.setReturnOrderResult(waterOrderVo.getCancelResult());
                }
            }
        }

        return waterOrderMapper.updateWaterOrder(waterOrderVo);
    }

    /**
     * 统计站点订单数量
     * @param stationId
     * @return
     */
    @Override
    public Map<String, Integer> getOrderNumByStation(Long stationId) {
        WaterOrderVo waterOrderVo = new WaterOrderVo();
        waterOrderVo.setStationId(stationId);
        waterOrderVo.setCreateTime(DateUtils.getNowDate());
        return waterOrderMapper.getOrderNumByStation(waterOrderVo);
    }

    /**
     * 根据站点查询订单信息
     * @param waterOrderVo 订单
     * @return
     */
    @Override
    public List<WaterOrderVo> getWaterOrderListByStationId(WaterOrderVo waterOrderVo) {
        return waterOrderMapper.getWaterOrderListByStationId(waterOrderVo);
    }

    /**
     * 修改订单完成状态（送水端）
     * @param waterOrderVo
     * @return
     */
    @Override
    public int updateCompleteState(WaterOrderVo waterOrderVo) {
        //设置送达时间
        waterOrderVo.setDelieverOver(DateUtils.getNowDate());
        return waterOrderMapper.updateWaterOrder(waterOrderVo);
    }

    /**
     * 修改订单确认状态（订水端）
     * @param waterOrderVo
     * @return
     */
    @Override
    public int updateConfirmState(WaterOrderVo waterOrderVo) {
        int i = 0;
        //判断用户是否点击确认收货或确认收款
        if (waterOrderVo.getConfirmState() == 1){
            waterOrderVo.setOrderState(4);
            waterOrderVo.setCompleteState(1);
            waterOrderVo.setTakeTime(DateUtils.getNowDate());
            waterOrderVo.setFinishTime(DateUtils.getNowDate());
            i += waterOrderMapper.updateWaterOrder(waterOrderVo);
        }else if (waterOrderVo.getConfirmState() == 2){
            waterOrderVo.setOrderState(6);
            waterOrderVo.setCompleteState(2);
            waterOrderVo.setFinishTime(DateUtils.getNowDate());
            i += waterOrderMapper.updateWaterOrder(waterOrderVo);
        }
        return i;
    }

    /**
     * 根据用户查询订单数量
     * @param userId
     * @return
     */
    @Override
    public Map<String, Integer> getOrderNumByUser(Long userId) {
        Map<String, Integer> map = new HashMap<>();
        WaterOrderVo waterOrderVo = new WaterOrderVo();
        waterOrderVo.setUserId(userId);
        //待付款数量
        waterOrderVo.setOrderState(1);
        Map<String, Integer> dfk = waterOrderMapper.getOrderNumByUser(waterOrderVo);
        map.put("dfk",dfk.get("orderNum"));
        //待接单数量
        waterOrderVo.setOrderState(2);
        Map<String, Integer> djd = waterOrderMapper.getOrderNumByUser(waterOrderVo);
        map.put("djd",djd.get("orderNum"));
        //进行中数量
        waterOrderVo.setOrderState(3);
        Map<String, Integer> jxz = waterOrderMapper.getOrderNumByUser(waterOrderVo);
        map.put("jxz",jxz.get("orderNum"));
        //已完成数量
        waterOrderVo.setOrderState(4);
        Map<String, Integer> ywc = waterOrderMapper.getOrderNumByUser(waterOrderVo);
        map.put("ywc",ywc.get("orderNum"));
        return map;
    }

    /**
     * 查询今天和昨天的所有订单
     * @return
     */
    @Override
    public List<WaterOrder> selectOrderListByTime() {
        return waterOrderMapper.selectOrderListByTime();
    }

    /**
     * PC端首页统计
     * @return
     */
    @Override
    public List<Map<String, Integer>> countOrderNum() {
        //获取当前年份
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(DateUtils.getNowDate());
        int year = calendar.get(Calendar.YEAR);
        //统计普通订单
        List<Map<String, Integer>> pt = waterOrderMapper.countOrderNumByPt(year);
        //统计退款订单
        List<Map<String, Integer>> tk = waterOrderMapper.countOrderNumByTk(year);
        //返回列表
        List<Map<String,Integer>> tjList = new ArrayList<>();
        for (Map<String, Integer> map : pt) {
            for (Map<String, Integer> map1 : tk) {
                if (map.get("month").equals(map1.get("month"))){
                    Map<String,Integer> tj = new HashMap<>();
                    tj.put("month",map.get("month"));
                    tj.put("pt",map.get("count"));
                    tj.put("tk",map1.get("count"));
                    tjList.add(tj);
                }
            }
        }
        return tjList;
    }

    /**
     * 新增退款订单
     * @param waterOrderVo
     * @return
     */
    @Override
    public int addReturnOrder(WaterOrderVo waterOrderVo) {
        waterOrderVo.setCreateUser(waterOrderVo.getUserId().toString());
        waterOrderVo.setCreateTime(DateUtils.getNowDate());
        waterOrderVo.setOrderNum(getOrerNum());
        waterOrderVo.setOrderState(3);
        waterOrderVo.setOrderType(2);
        return waterOrderMapper.insertWaterOrder(waterOrderVo);
    }

    /**
     * 修改待付款订单状态(订水端)
     * @param waterOrderVo
     * @return
     */
    @Override
    public int updateOrderPayType(WaterOrderVo waterOrderVo) {
        //判断是否为水票支付,为水票支付,则订单直接变为待接单
        if (waterOrderVo.getPayType() == 2){
            waterOrderVo.setOrderState(2);
            waterOrderVo.setPayState(1);
        }
        return waterOrderMapper.updateWaterOrder(waterOrderVo);
    }
}
